#========================================================================================
# package      DE_EPAGES::AppStore::API::Url
# state        public
# description  API for helpers to build URLs for the AppStore client.
#========================================================================================
package DE_EPAGES::AppStore::API::Url;
use base Exporter;
use DE_EPAGES::Core::API::TestParameter qw ( TestObject TestString );
use DE_EPAGES::Shop::API::Url qw ( BuildShopUrl );

use strict;

our @EXPORT_OK = qw (
  BuildRedirectUrl
);

#========================================================================================
# function     BuildRedirectUrl
# state        public
#----------------------------------------------------------------------------------------
# syntax       BuildRedirectUrl( $Servlet, $CallbackURLBase, $appID, $dev );
#----------------------------------------------------------------------------------------
# description  Adds the necessary query params to construct redirect URL for the browser.
#----------------------------------------------------------------------------------------
# input        $Servlet | servlet | object
# input        $CallbackURL | base url for building callback | string
# input        $appID | app id | string
# input        $dev | developer app flag | boolean
# return       $RedirectUrl | URL to redirect to | URI
#========================================================================================
sub BuildRedirectUrl {
    my ( $Servlet, $CallbackURLBase, $appID, $dev ) = @_;
    TestObject( 'Servlet', $Servlet );
    TestString( 'CallbackURLBase', $CallbackURLBase );
    TestString( 'appID',       $appID );

    my $Shop = $Servlet->object->getSite;
    my $epagesjBaseUrl =
        $Shop->get('ProtocolAndServerSSL')
      . '/rs/shops/'
      . $Shop->get('WebServerScriptNamePart');

    my $hQueryParams = {};
    if ($dev) {
        $hQueryParams = {
            'appID'             => $appID,
            'ViewAction'        => 'MBO-ViewDeveloperApp',
            'TestAuthorization' => $dev,
        };
    } else {
        $hQueryParams = {
            'appID'      => $appID,
            'ViewAction' => 'MBO-ViewAppDetails',
        };
    }
    my $ReturnUrl = BuildShopUrl(
         $Shop,
         $hQueryParams,
        {
            'Type'   => 'admin',
            'UseSSL' => 1
        },
        $Servlet
    );

    my $CallbackURL = URI->new($CallbackURLBase);
    $CallbackURL->query_form(
        $CallbackURL->query_form(),
        'return_url'       => $ReturnUrl,
        'api_url'          => $epagesjBaseUrl,
    );
    return $CallbackURL;
}

1;
