#========================================================================================
# package      DE_EPAGES::AvaTax::API::Constants
# base         Exporter
# state        public
# description  Constants for AvaTax
#========================================================================================
package DE_EPAGES::AvaTax::API::Constants;
use base Exporter;

use strict;

our @EXPORT_OK = qw (
    AVATAX_SOAP_URN
    AVATAX_TEXTCASE_Default
    AVATAX_TEXTCASE_Upper
    AVATAX_TEXTCASE_Mixed
    AVATAX_RESULTCODE_Success
    AVATAX_RESULTCODE_Warning
    AVATAX_RESULTCODE_Error
    AVATAX_RESULTCODE_Exception
    AVATAX_DOCUMENTTYPE_SalesOrder
    AVATAX_DOCUMENTTYPE_SalesInvoice
    AVATAX_DOCUMENTTYPE_PurchaseOrder
    AVATAX_DOCUMENTTYPE_PurchaseInvoice
    AVATAX_DOCUMENTTYPE_ReturnOrder
    AVATAX_DOCUMENTTYPE_ReturnInvoice
    AVATAX_DETAILLEVEL_Summary
    AVATAX_DETAILLEVEL_Document
    AVATAX_DETAILLEVEL_Line
    AVATAX_DETAILLEVEL_Tax
    AVATAX_DETAILLEVEL_Diagnostic
    AVATAX_TAXOVERRIDETYPE_None
    AVATAX_TAXOVERRIDETYPE_TaxAmount
    AVATAX_TAXOVERRIDETYPE_Exemption
    AVATAX_TAXOVERRIDETYPE_TaxDate
    AVATAX_SERVICELEVEL_Automatic
    AVATAX_SERVICELEVEL_Local
    AVATAX_SERVICELEVEL_Remote
    AVATAX_TAXCODE_Normal
    AVATAX_TAXCODE_None
    AVATAX_CustomerClassAttributeName
    AVATAX_WEBSERVICE_Tax
    AVATAX_WEBSERVICE_Address
    AVATAX_REQUEST_DestinationCode
    AVATAX_REQUEST_OriginCode
    AVATAX_REQUEST_AllowedCurrencyID
    AVATAX_REQUEST_LineMaxLengthOfDescription
    AVATAX_REQUEST_LineMaxLengthOfItemCode
    AVATAX_ADJUSTTAX_REASON_NotAdjusted
    AVATAX_ADJUSTTAX_REASON_SourcingIssue
    AVATAX_ADJUSTTAX_REASON_ReconciledWithGeneralLedger
    AVATAX_ADJUSTTAX_REASON_ExemptionCertificateApplied
    AVATAX_ADJUSTTAX_REASON_PriceOrQuantityAdjusted
    AVATAX_ADJUSTTAX_REASON_ItemReturned
    AVATAX_ADJUSTTAX_REASON_ItemExchanged
    AVATAX_ADJUSTTAX_REASON_BadDebt
    AVATAX_ADJUSTTAX_REASON_Other
    AVATAX_RETURNCODE_NO_ADDRESS_CHECK
    AVATAX_REQUEST_MaxLengthOfNo
    AVATAX_WEBSERVICE_ERROR
    AVATAX_GETTAX_SUCCESS
    AVATAX_ADJUSTTAX_SUCCESS
    AVATAX_CANCELTAX_SUCCESS
    $AVATAX_LINEITEM_TYPES
    $AVATAX_COUNTRIES_SUPPORTING_ADDRESS_VALIDATION
);

use constant AVATAX_SOAP_URN => 'http://avatax.avalara.com/services';

#    /**
#     * Default casing for the account.
#     */
use constant AVATAX_TEXTCASE_Default => 'Default';

#    /**
#     *  Upper case.
#     */
use constant AVATAX_TEXTCASE_Upper   => 'Upper';

#    /**
#     *  Mixed case.
#     */
use constant AVATAX_TEXTCASE_Mixed   => 'Mixed';

#    /**
#     * Operation succeeded.
#     */
use constant AVATAX_RESULTCODE_Success => 'Success';

#    /**
#     *  Warnings occured, operation succeeded.
#     */
use constant AVATAX_RESULTCODE_Warning => 'Warning';

#    /**
#     * Errors occured, operation failed.
#     */
use constant AVATAX_RESULTCODE_Error => 'Error';

#    /**
#     *  Unexpected exceptions occurred, operation failed.
#     */
use constant AVATAX_RESULTCODE_Exception => 'Exception';

#    /**
#     *  Sales Order, estimate or quote. This is a temporary document type and is not saved in tax history.
#     * {@link GetTaxResult} will return with a {@link DocStatus} of <b>Temporary</b>.
#     */
use constant AVATAX_DOCUMENTTYPE_SalesOrder => 'SalesOrder';

#    /**
#     *  The document is a permanent invoice; document and tax calculation results are saved in the tax history.
#     * {@link GetTaxResult} will return with a {@link DocStatus} of <b>Saved</b>
#     */
use constant AVATAX_DOCUMENTTYPE_SalesInvoice => 'SalesInvoice';

#    /**
#     * Purchase order, estimate, or quote. This is a temporary document type and is not saved in tax history.
#     * {@link GetTaxResult} will return with a {@link DocStatus} of <b>Temporary</b>.
#     */
use constant AVATAX_DOCOUMENTTYPE_PurchaseOrder => 'PurchaseOrder';

#    /**
#     *  The document is a permanent invoice; document and tax calculation results are saved in the tax history.
#     * {@link GetTaxResult} will return with a {@link DocStatus} of <b>Saved</b>.
#     */
use constant AVATAX_DOCUMENTTYPE_PurchaseInvoice => 'PurchaseInvoice';

#    /**
#     * Sales Return Order. This is a temporary document type and is not saved in tax history.
#     * {@link GetTaxResult} will return with a {@link DocStatus} of <b>Temporary</b>.
#     */
use constant AVATAX_DOCUMENTTYPE_ReturnOrder => 'ReturnOrder';


#    /**
#     *  The document is a permanent sales return invoice; document and tax calculation results are
#     * saved in the tax history {@link GetTaxResult} will return with a {@link DocStatus}
#     * of <b>Saved</b>.
#     */
use constant AVATAX_DOCUMENTTYPE_ReturnInvoice => 'ReturnInvoice';

#    /**
#     * Reserved for future use.
#     */
use constant AVATAX_DETAILLEVEL_Summary => 'Summary';

#    /**
#     *  Document ({@link GetTaxResult}) level details; {@link ArrayOfTaxLine} will not be returned.
#     */
use constant AVATAX_DETAILLEVEL_Document => 'Document';

#    /**
#     *  Line level details (includes Document details). {@link ArrayOfTaxLine} will
#     * be returned but {@link ArrayOfTaxDetail} will not be returned.
#     */
use constant AVATAX_DETAILLEVEL_Line => 'Line';

#    /**
#     *  Tax jurisdiction level details (includes Document, {@link ArrayOfTaxLine},
#     * and {@link ArrayOfTaxDetail})
#     */
use constant AVATAX_DETAILLEVEL_Tax => 'Tax';

# TODO API-Doc zu AVATAX_DETAILLEVEL_Diagnostic?
use constant AVATAX_DETAILLEVEL_Diagnostic => 'Diagnostic';

#    /**
#     * Default value.
#     */
use constant AVATAX_TAXOVERRIDETYPE_None => 'None';

#    /**
#     * The TaxAmount overrides the total tax for the document.
#     */
use constant AVATAX_TAXOVERRIDETYPE_TaxAmount => 'TaxAmount';

#    /**
#     * Exemption certificates are overridden making the document taxable.
#     */
use constant AVATAX_TAXOVERRIDETYPE_Exemption => 'Exemption';

#    /**
#     * The TaxDate overrides the DocDate as the effective date used for tax calculation.
#     */
use constant AVATAX_TAXOVERRIDETYPE_TaxDate => 'TaxDate';

#    /**
#     * Automated handling by local and/or remote server.
#     */
use constant AVATAX_SERVICELEVEL_Automatic => 'Automatic';

#    /**
#     * AvaLocal server only. Lines requiring remote will not be calculated.
#     */
use constant AVATAX_SERVICELEVEL_Local => 'Local';

#    /**
#     * All lines are calculated by AvaTax remote server.
#     */
use constant AVATAX_SERVICELEVEL_Remote => 'Remote';

# regular taxable
use constant AVATAX_TAXCODE_Normal => 'P0000000';

# non-taxable
use constant AVATAX_TAXCODE_None => 'NT';

# non-taxable
use constant AVATAX_CustomerClassAttributeName => 'AvataxTaxExemption';

#    /**
#     * Constant to identify the tax webservice.
#     */
use constant AVATAX_WEBSERVICE_Tax => 'AvaTaxWebserviceTax';

#    /**
#     * Constant to identify the address webservice.
#     */
use constant AVATAX_WEBSERVICE_Address => 'AvaTaxWebserviceAddress';

#    /**
#     * Constant to identify the address destination code.
#     */
use constant AVATAX_REQUEST_DestinationCode => 'Dest';

#    /**
#     * Constant to identify the address origin code.
#     */
use constant AVATAX_REQUEST_OriginCode => 'Origin';

#    /**
#     * Constant to identify the currency id use in the request.
#     */
use constant AVATAX_REQUEST_AllowedCurrencyID => 'USD';

#    /**
#     * Constant to identify the max lenght description of the Line.
#     */
use constant AVATAX_REQUEST_LineMaxLengthOfDescription => 255;

#    /**
#     * Constant to identify the max lenght description of the ItemCode.
#     */
use constant AVATAX_REQUEST_LineMaxLengthOfItemCode => 50;

#    /**
#     * Constant to identify the adjustment reason: Not Adjusted.
#     */
use constant AVATAX_ADJUSTTAX_REASON_NotAdjusted => 0;

#    /**
#     * Constant to identify the adjustment reason: Sourcing Issue.
#     */
use constant AVATAX_ADJUSTTAX_REASON_SourcingIssue => 1;

#    /**
#     * Constant to identify the adjustment reason: Reconciled with General Ledger.
#     */
use constant AVATAX_ADJUSTTAX_REASON_ReconciledWithGeneralLedger => 2;

#    /**
#     * Constant to identify the adjustment reason: Exemption Certificate Applied.
#     */
use constant AVATAX_ADJUSTTAX_REASON_ExemptionCertificateApplied => 3;

#    /**
#     * Constant to identify the adjustment reason: Price or Quantity Adjusted.
#     */
use constant AVATAX_ADJUSTTAX_REASON_PriceOrQuantityAdjusted => 4;

#    /**
#     * Constant to identify the adjustment reason: Item Returned.
#     */
use constant AVATAX_ADJUSTTAX_REASON_ItemReturned => 5;

#    /**
#     * Constant to identify the adjustment reason: Item Exchanged.
#     */
use constant AVATAX_ADJUSTTAX_REASON_ItemExchanged => 6;

#    /**
#     * Constant to identify the adjustment reason: Bad Debt.
#     */
use constant AVATAX_ADJUSTTAX_REASON_BadDebt => 7;

#    /**
#     * Constant to identify the adjustment reason: Other.
#     */
use constant AVATAX_ADJUSTTAX_REASON_Other => 8;

#    /**
#     * Constant to identify the return code when no address check is performed
#     */
use constant AVATAX_RETURNCODE_NO_ADDRESS_CHECK => 'noavatax';

#    /**
#     * Constant to identify the maximum length of attribute No of Line
#     */
use constant AVATAX_REQUEST_MaxLengthOfNo => 50;

use constant AVATAX_WEBSERVICE_ERROR => 'AVATAX_WEBSERVICE_ERROR';
use constant AVATAX_GETTAX_SUCCESS => 'AVATAX_GETTAX_SUCCESS';
use constant AVATAX_ADJUSTTAX_SUCCESS => 'AVATAX_ADJUSTTAX_SUCCESS';
use constant AVATAX_CANCELTAX_SUCCESS => 'AVATAX_CANCELTAX_SUCCESS';

#    /**
#     * Constant to specifie the countries (by code2) that support avatax address validation.
#     */
our $AVATAX_COUNTRIES_SUPPORTING_ADDRESS_VALIDATION = [ 
    124, # = CA
    840, # = US
];

#    /**
#     * List with LineItems which will be listed at transactions list in Avatax backoffice.
#     */
our $AVATAX_LINEITEM_TYPES = ['Product', 'PaymentMethod', 'ShippingMethod'];
1;