#========================================================================================
# package      DE_EPAGES::CMS::API::Object::PagerChildren
# state        public
# base         DE_EPAGES::Presentation::API::Object::PagerChildren
#----------------------------------------------------------------------------------------
# description  Pager to display the list of child objects which have a certain class.
#----------------------------------------------------------------------------------------
# example      sub ViewCustomers {
#                   my $self = shift;
#                   my ($Servlet) = @_;
#
#                   my $Shop = $Servlet->object;
#                   my $Pager = DE_EPAGES::Presentation::API::Object::PagerChildren->new({
#                       'Servlet'  => $Servlet,
#                       'Object'   => $Shop->folder('Customers'),
#                       'PageSize' => 25,
#                       'OrderBy'  => 'Alias'
#                   });
#                   return $Pager->page;
#               }
#========================================================================================
package DE_EPAGES::CMS::API::Object::PagerChildren;
use base DE_EPAGES::Presentation::API::Object::PagerChildren;

use strict;

#========================================================================================
# function     countItems
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Items = $Pager->countItems;
#----------------------------------------------------------------------------------------
# description  Returns the total number of child objects.
#----------------------------------------------------------------------------------------
# return       $Items | total number of items | integer
#========================================================================================
sub countItems {
    my $self = shift;
    my $Object = $self->get('Object');
    return scalar @{$Object->childrenByClass('Category')};
}

#========================================================================================
# function     items
# state        public
#----------------------------------------------------------------------------------------
# syntax       $aItems = $Pager->items($Page);
#----------------------------------------------------------------------------------------
# description  Returns all objects of one page.
#----------------------------------------------------------------------------------------
# input        $Page | current page number | integer
# return       $aItems | list of objects | ref.array.object
#========================================================================================
sub items {
    my $self = shift;
    my ($Page) = @_;
    my $Object = $self->get('Object');
    my $Children = $self->sortObjects($Object->childrenByClass('Category'));
    my @Items = @{$Children}[$self->firstItemOfPage($Page) .. $self->lastItemOfPage($Page)];
    return \@Items;
}

1;
