#========================================================================================
# package      DE_EPAGES::Catalog::API::CategorySequenceService
# state        public
#----------------------------------------------------------------------------------------
# description  Manages the category over rest api
#========================================================================================
package DE_EPAGES::Catalog::API::CategorySequenceService;
use base DE_EPAGES::Core::API::Object::BaseObject;

use DE_EPAGES::Core::API::Error qw ( Error );
use List::MoreUtils qw ( uniq );

use strict;



sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;
}
sub class {
    return 'Category';
}

sub getCategorySequence {
    my $self = shift;
    my ($category, $IncludeInvisible) = @_;

    return $self->_getCurrentCategorySequence($category);
}

sub setCategorySequence {

    my $self = shift;
    my ($category, $aCategorySequence, $IncludeInvisible) = @_;

    my $aCurrentCategories = $self->_getCurrentCategorySequence($category );

    my $IsValid = $self->_checkIfSequenceIsValid( $aCategorySequence, $aCurrentCategories);
    if(!$IsValid) {
        Error('BadRequest', {'Reason' => 'one or more category alias is not valid!'});
    }

    # convert array of existing visible categories into hash.
    my %hCategories = map { $_ => 1} @$aCategorySequence;

    # push sort-order of the input categories into an array.
    my @aSortNums;
    my @Children = @{$category->children()};
    foreach my $child (@Children){
        my $key = $child->get('Alias');
        push @aSortNums, $child->get('Position') if exists $hCategories{$key};
    }

    # sort the array.
    @aSortNums = sort { $a <=> $b } @aSortNums;

    # Assign sort-order to new sequence in hash.
    my %hCategorySortNum;
    my $pos = 0; ## no critic (ProhibitMagicNumbers)
    foreach my $category (@$aCategorySequence){
        $hCategorySortNum{$category} .= $aSortNums[$pos];
        $pos++;
    }

    # Assign new position / sort order
    foreach my $child (@Children){
        my $key = $child->get('Alias');
        $child->set({'Position'=>$hCategorySortNum{$key}}) if exists $hCategorySortNum{$key};
    }
    return 1;

}



sub _checkIfSequenceIsValid {
    my $self = shift;
    my ( $aCategorySequence, $aCurrentCategories ) = @_;

    # check if new category sequence does not contain duplicates
    my $numCategoriesWithoutDuplicates = uniq @$aCategorySequence;
    if($numCategoriesWithoutDuplicates !=  @$aCategorySequence) {
        return 0;
    }

    # check every new sequence element is in existing categories list
   foreach my $element (@{$aCategorySequence}){
       if(!(grep {$_ eq $element} @{$aCurrentCategories})){
           return 0;
       }
   }

    return 1;
}

sub _getCurrentCategorySequence(){
    my $self = shift;
    my ($category) = @_;

    my @Categories;
    @Categories = @{$category->get('SubCategories')};

    my @ValidCategegories = grep { _isCategory($_) } @Categories;

    my @aCategories;
    foreach my $item (@ValidCategegories){
            push @aCategories, $item->get('Alias');
    }
    return \@aCategories;
}

sub _isCategory {
    my ($Category) = @_;
    return $Category->class()->isSubClassOf(class());
}
1;