#========================================================================================
# package      DE_EPAGES::Catalog::API::Resource::CategorySequence
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  implements the REST resource for altering category sequence
#========================================================================================
package DE_EPAGES::Catalog::API::Resource::CategorySequence;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Object::API::Object::Locale;
use DE_EPAGES::Trigger::API::BatchProcessor qw ( RunBatchProcess );
use DE_EPAGES::Shop::API::Resource::ShopRequestContext;
use DE_EPAGES::Catalog::API::CategorySequenceService;

use feature 'switch';
use JSON;

use strict;



sub service {
    return LoadObjectByPath('/RestServices/CategorySequence');
}

sub class {
    return 'Category';
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ],
        PUT => [
            ['put', 'application/json'],
            ['put', 'application/vnd.epages.v1+json'],
        ], }->{$RequestMethod};
}



sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/categories/([^/]+)/sequence/?$|;
    return $1;
}



sub requestContext {
    my $self = shift;
    my ( $Site, $GUID, $Request ) = @_;
    return $self->SUPER::requestContext( $Site, $GUID, $Request );
}



sub params {
    my $self = shift;
    my ( $ActionName, $Object, $Request ) = @_;

    given ($ActionName) {
        when ('get') {
            return [$Object];
        } when ('put') {
            return [$Object, decode_json($Request->decoded_content())];
        }
        default {
            return [$Object];
        }
    }
}



sub get{
    my $self = shift;
    my ($Category) = @_;
    my $CategorySequenceService = DE_EPAGES::Catalog::API::CategorySequenceService->new();
    return $CategorySequenceService->getCategorySequence($Category);
}



sub put{
    my $self = shift;
    my ($Category, $hRequestBody, $IncludeInvisible) = @_;

    my $CategorySequenceService = DE_EPAGES::Catalog::API::CategorySequenceService->new();

    RunBatchProcess('UpdateCategories', sub {
        $CategorySequenceService->setCategorySequence($Category, $hRequestBody);
    });

    return $self->get($Category, $IncludeInvisible);

}

1;
