#========================================================================================
# package      DE_EPAGES::Catalog::t::unit::CategoryResource
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::Catalog::API::Resource::Category
#========================================================================================
package DE_EPAGES::Catalog::t::unit::CategoryResource;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Catalog::API::Resource::Category;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::Mockify qw ( GetParametersFromMockifyCall );
use DE_EPAGES::Test::Mock::Mockery;
use Test::More;

use strict;



sub test {
    my $self = shift;

    $self->test_get();
    $self->test_post();
    $self->test_put();

    done_testing();
}



sub test_get {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Resource = $Mockery->get('SUT');
    my $Category = $Mockery->get('Category');
    my $Locale = 'de_DE';

    my $hCategoryData = $Resource->get($Category, $Locale);

    is_deeply($hCategoryData, {'test' => 'data'}, "$SubTestName - test if the expected data was returned");
}



sub test_post {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Resource = $Mockery->get('SUT');
    my $Category = $Mockery->get('Category');
    my $Locale = 'de_DE';

    my $hRequestBody = {
        'name' => 'testcategory'
    };

    my $hCategoryData = $Resource->post($Category, $Locale, $hRequestBody);

    my $CategoryService = $Mockery->get('CategoryService');
    my $aParams = GetParametersFromMockifyCall($CategoryService, 'createCategory');
    my $hRequestParams = $aParams->[2];
    is_deeply($hRequestParams, {'name' => 'testcategory'}, "$SubTestName - test if createCategory was called with correct data");
    is_deeply($hCategoryData, {'test' => 'data'}, "$SubTestName - test if the expected data was returned");
}



sub test_put {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Resource = $Mockery->get('SUT');
    my $Category = $Mockery->get('Category');
    my $Locale = 'de_DE';

    my $hRequestBody = {
        'name' => 'testcategory'
    };

    my $hCategoryData = $Resource->put($Category, $Locale, $hRequestBody);

    my $CategoryService = $Mockery->get('CategoryService');
    my $aParams = GetParametersFromMockifyCall($CategoryService, 'updateCategory');
    my $hRequestParams = $aParams->[2];
    is_deeply($hRequestParams, {'name' => 'testcategory'}, "$SubTestName - test if updateCategory was called with correct data");
    is_deeply($hCategoryData, {'test' => 'data'}, "$SubTestName - test if the expected data was returned");
}



sub _createMocks {
    my $self = shift;
    my $Mockery = DE_EPAGES::Test::Mock::Mockery->new();

    $Mockery->register('SUT', ['Context', 'CategoryService'], sub {
        my ($Context, $CategoryService) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Catalog::API::Resource::Category', []);
        $Mockify->addMockWithReturnValueAndParameterCheck('_createShopRequestContext', $Context, [{'object' => 'DE_EPAGES::Shop::API::Object::Shop'}]);
        $Mockify->addMockWithReturnValue('_createCategoryService', $CategoryService);
        $Mockify->mock('_RunBatchProcess', sub {
            my $MockedShift = shift;
            my ($BatchTaskName, $cSub) = @_;
            $cSub->();
        });
        return $Mockify->getMockObject();
    });
    $Mockery->register('Category', ['Shop'], sub {
        my ($Shop) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Content::API::Object::Category', {
            'Site' => $Shop,
        });
        return $Mockify->getMockObject();
    });
    $Mockery->register('CategoryService', ['Category'], sub {
        my ($Category) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Catalog::API::CategoryService', []);
        $Mockify->addMockWithReturnValueAndParameterCheck('getCategoryData', {'test' => 'data'}, [
            {'object' => 'DE_EPAGES::Content::API::Object::Category'},
            {'string' => 'de_DE'},
            {'object' => 'DE_EPAGES::Shop::API::Resource::ShopRequestContext'},
            {'any' => undef},
        ]);
        $Mockify->addMockWithReturnValueAndParameterCheck('createCategory', $Category, [
            {'object' => 'DE_EPAGES::Content::API::Object::Category'},
            {'string' => 'de_DE'},
            'hashref',
        ]);
        $Mockify->addMockWithReturnValueAndParameterCheck('updateCategory', $Category, [
            {'object' => 'DE_EPAGES::Content::API::Object::Category'},
            {'string' => 'de_DE'},
            'hashref',
        ]);
        return $Mockify->getMockObject();
    });
    $Mockery->register('Shop', [], sub {
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', {
        });
        return $Mockify->getMockObject();
    });
    $Mockery->register('Context', ['Shop'], sub {
        my ($Shop) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Shop::API::Resource::ShopRequestContext', [$Shop]);
        $Mockify->addMockWithReturnValueAndParameterCheck('validLocale', 'de_DE', [{'string' => 'de_DE'}]);
        return $Mockify->getMockObject();
    });

    return $Mockery->assemble();
}

__PACKAGE__->runScript();