#========================================================================================
# package      DE_EPAGES::Design::UI::JSON
# state        public
# base         DE_EPAGES::Presentation::UI::JSON
# description  SaveAction for the customizable buttons.
#========================================================================================
package DE_EPAGES::Design::UI::JSON;
use base DE_EPAGES::Presentation::UI::JSON;

use strict;
use JSON;
use DE_EPAGES::Design::API::Constants qw ( CUSTOMIZABLE_BUTTONS );
use DE_EPAGES::Design::API::Style qw ( InvalidateAllShopStyles ValidateButtonValues );

#========================================================================================
# function     JSONSaveCustomizableButtons
# state        public
#----------------------------------------------------------------------------------------
# syntax       JSONSaveCustomizableButtons($Servlet);
#----------------------------------------------------------------------------------------
# description  Method to save customizable buttons settings.
#               Triggers hook to save settings for the customizable basket button.
#----------------------------------------------------------------------------------------
# input        $Servlet | servlet object | object
#========================================================================================
sub JSONSaveCustomizableButtons {
    my $self = shift;
    my ($Servlet) = @_;

    my $Shop = $Servlet->object;
    my $Form = $Servlet->form;

    my $DefaultStyle = $Shop->get('DefaultStyle');

    # Get allowed button styling attributes.
    my $hCUSTOMIZABLEBUTTONS = CUSTOMIZABLE_BUTTONS();
    # Get button settings.
    my $hCustomizableButtons = from_json($Form->value('CustomizableButtons'));

    # Validation
    my $hCustomizableButtonsForJSON->{'CustomizableButtons'} = ValidateButtonValues($Form, $hCustomizableButtons, $hCUSTOMIZABLEBUTTONS);
    if ($Form->existsFormError()) {
        my $aFormErrors = $Form->formErrors();
        foreach my $hFormError (@$aFormErrors) {
            $hFormError->{'Form'} = 'CustomizableButtons';
        }
    }
    $Form->executeFormError();

    $DefaultStyle->set($hCustomizableButtonsForJSON);
    my $hParams = {
        'ResponseContent' => $hCustomizableButtonsForJSON,
        'Style' => $DefaultStyle,
        'Form' => $Form,
    };
    InvalidateAllShopStyles($Shop);
    $Servlet->writeContentOutput($hParams->{'ResponseContent'});
}

1;
