#========================================================================================
# package      DE_EPAGES::ERPLexware::API::Cartridge
# base         DE_EPAGES::Shop::API::ShopInstaller
# state        public
#----------------------------------------------------------------------------------------
# description  This is the main cartridge class for install/patch/uninstall.
#========================================================================================
package DE_EPAGES::ERPLexware::API::Cartridge;
use base qw ( DE_EPAGES::Shop::API::ShopInstaller );

use DE_EPAGES::Object::API::XML::ObjectImportHandler qw (ImportObjects );
use DE_EPAGES::Object::API::XML::ObjectDeleteHandler qw (DeleteObjects );

use strict;

#========================================================================================
# function     new
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer = DE_EPAGES::ERPLexware::API::Cartridge->new(%options);
#----------------------------------------------------------------------------------------
# description  Creates a new installer object of DE_EPAGES::ERPLexware.
#----------------------------------------------------------------------------------------
# input        %options | options for un/install
#               <ul>
#                 <li>IsRecursive - recursive un/installation of required or dependent
#                     cartridges
#               </ul>
#               | hash
# return       $Installer | cartridge installer | object
#========================================================================================
sub new {
    my ($class, %options) = @_;

    my $self = __PACKAGE__->SUPER::new(
        %options,
        'CartridgeDirectory' => 'DE_EPAGES/ERPLexware',
        'Version'            => '7.6.0',
        'Patches'            => ['6.17.45','6.17.45.1','6.17.46','6.17.47','6.17.47.1','6.17.48','6.17.48.1','6.17.49','6.17.49.1','6.17.50','6.17.51','6.17.51.1','6.17.52','6.17.53','7.0.0','7.1.0','7.2.0','7.3.0','7.4.0','7.5.0'],
    );
    return bless $self, $class;
}

#========================================================================================
# function     install
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer->install;
#----------------------------------------------------------------------------------------
# description  Installs the cartridge.
#========================================================================================
sub install {
    my $self = shift;

    $self->startInstall;
    $self->SUPER::install;
    ImportObjects( $self->xmlDirectory . '/ClientApplications.xml', '/');
    ImportObjects( $self->xmlDirectory . '/ERPSystem.xml',   '/');
    $self->finishInstall;
    return;
}

#========================================================================================
# function     uninstall
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer->uninstall;
#----------------------------------------------------------------------------------------
# description  Uninstalls the cartridge.
#========================================================================================
sub uninstall {
    my $self = shift;

    $self->startUninstall;
    $self->SUPER::uninstall;
    DeleteObjects( $self->xmlDirectory .'/ClientApplications.xml', '/');
    DeleteObjects( $self->xmlDirectory .'/ERPSystem.xml',   '/');
    $self->finishUninstall;
    return;
}

1;
