#========================================================================================
# package      DE_EPAGES::Event::API::Batch::ProductEventBatchProcessHandler
# base         DE_EPAGES::Trigger::API::Object::BatchProcessHandler
# state        public
#----------------------------------------------------------------------------------------
# description  BatchProcessHandler for ProductEvents
#========================================================================================
package DE_EPAGES::Event::API::Batch::ProductEventBatchProcessHandler;
use base DE_EPAGES::Trigger::API::Object::BatchProcessHandler;

use DE_EPAGES::Event::API::ProductEventService;
use feature 'switch';

use DE_EPAGES::Event::API::Constants qw (
    EVENT_PRODUCT_CREATION
    EVENT_PRODUCT_DELETION
    EVENT_PRODUCT_UPDATE
);

use strict;



#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       new( $hOptions );
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# input        $hOptions |<ul><li>BatchSize - integer > 1 (optional)</li></ul> | ref.hash
# return       $self | self | DE_EPAGES::Event::API::Batch::ProductEventBatchProcessHandler
#========================================================================================
sub new {
    my $class = shift;
    my ($hOptions) = @_;
    return $class->SUPER::new($hOptions);
}



sub processItemList {
    my $self = shift;

    my $hEvents = {};
    my $aEventItems = $self->items();

    # iterate over events and collect only one event per product
    for my $EventItem (@$aEventItems) {

        my $Product = $EventItem->{'Object'};
        my $ProductGUID = $Product->guid();

        $hEvents->{$ProductGUID} = $EventItem;
    }

    my @ProductGUIDs = keys %$hEvents;
    for my $ProductGUID (@ProductGUIDs) {
        my $EventItem = $hEvents->{$ProductGUID};
        $self->processItem($EventItem);
    }

    $self->cleanupItems();
    return;
}



sub processItem {
    my $self = shift;
    my ($EventItem) = @_;

    my $ProductEventService = $self->_createProductEventService();
    my $EventType = $EventItem->{'Event'};
    my $Product = $EventItem->{'Object'};

    given ($EventType) {
        when(EVENT_PRODUCT_CREATION) {
            $ProductEventService->createProductCreationEvent($Product);
        }
        when(EVENT_PRODUCT_UPDATE) {
            $ProductEventService->createProductUpdateEvent($Product);
        }
        when(EVENT_PRODUCT_DELETION) {
            $ProductEventService->createProductDeletionEvent($Product);
        }
        default {
            warn 'Try to process event type which is not supported';
        }
    }

    return;
}


sub _createProductEventService {
    return DE_EPAGES::Event::API::ProductEventService->new();
}

1;