#========================================================================================
# package      DE_EPAGES::Event::API::Cartridge
# base         DE_EPAGES::Design::API::DesignInstaller
# state        public
#----------------------------------------------------------------------------------------
# description  This is the main cartridge class for install/patch/uninstall.
#========================================================================================
package DE_EPAGES::Event::API::Cartridge;
use base DE_EPAGES::Design::API::DesignInstaller;

use DE_EPAGES::Object::API::Factory qw ( LoadRootObject );

use strict;



#========================================================================================
# function     new
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer = DE_EPAGES::Event::API::Cartridge->new(%options);
#----------------------------------------------------------------------------------------
# description  Creates a new installer object of DE_EPAGES::Event.
#----------------------------------------------------------------------------------------
# input        %options | options for un/install
#               <ul>
#                 <li>IsRecursive - recursive un/installation of required or dependent
#                     cartridges
#               </ul>
#               | hash
# return       $Installer | cartridge installer | object
#========================================================================================
sub new {
    my ($class, %options) = @_;

    my $self = __PACKAGE__->SUPER::new(
        %options,
        'CartridgeDirectory' => 'DE_EPAGES/Event',
        'Version'            => '7.6.0',
        'Patches'            => ['6.17.52','6.17.53','7.0.0','7.1.0','7.2.0','7.3.0','7.4.0','7.5.0'],
    );
    return bless $self, $class;
}

#========================================================================================
# function     install
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer->install;
#----------------------------------------------------------------------------------------
# description  Installs the cartridge.
#========================================================================================
sub install {
    my $self = shift;

    $self->startInstall;
    $self->SUPER::install;
    $self->initEventQueueUrl;
    $self->finishInstall;
    return;
}

#========================================================================================
# function     uninstall
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer->uninstall;
#----------------------------------------------------------------------------------------
# description  Uninstalls the cartridge.
#========================================================================================
sub uninstall {
    my $self = shift;

    $self->startUninstall;
    $self->SUPER::uninstall;
    $self->finishUninstall;
    return;
}

#========================================================================================
# function     initEventQueueUrl
# state        private
#----------------------------------------------------------------------------------------
# syntax       initEventQueueUrl();
#----------------------------------------------------------------------------------------
# description  Initializes the EventQueueUrl with the ePagesJ Event Service URL.
#========================================================================================
sub initEventQueueUrl {
    my $self = shift;

    my $System = LoadRootObject();
    my $EPagesJBaseURL = $System->get('EPagesJBaseURL');
    my $EventQueueUrl = $EPagesJBaseURL . 'events';
    $System->set({'EventQueueUrl' => $EventQueueUrl});

    return;
}

1;