#========================================================================================
# package      DE_EPAGES::Event::API::CategoryEventService
# state        public
#----------------------------------------------------------------------------------------
# description  Notifies epagesJ about category events.
#========================================================================================
package DE_EPAGES::Event::API::CategoryEventService;
use base DE_EPAGES::Event::API::EventService;

use DE_EPAGES::Event::API::Constants qw (
    EVENT_CATEGORY_CREATION
    EVENT_CATEGORY_DELETION
    EVENT_CATEGORY_UPDATE
);

use DE_EPAGES::Object::API::Factory qw ( LoadRootObject );
use strict;

## no critic (ProhibitPrivateSubroutineUse)



#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       new();
#----------------------------------------------------------------------------------------
# description  Constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Event::API::CategoryEventService
#========================================================================================
sub new {
    my $class = shift;
    my $self = $class->SUPER::new();
    return $self;
}



sub _sendEvent {
    my $self = shift;
    my ($Object, $EventType) = @_;

    my $System = $self->_LoadRootObject();
    return if $System->get('EventCategories') != 1;

    $self->SUPER::_sendEvent($Object, $EventType);
    return;

}


sub createCategoryCreationEvent {
    my $self = shift;
    my ($Category) = @_;

    $self->_sendEvent($Category, EVENT_CATEGORY_CREATION);

    return;
}



sub createCategoryUpdateEvent {
    my $self = shift;
    my ($Category) = @_;

    $self->_sendEvent($Category, EVENT_CATEGORY_UPDATE);

    return;
}



sub createCategoryDeletionEvent {
    my $self = shift;
    my ($Category) = @_;

    $self->_sendEvent($Category, EVENT_CATEGORY_DELETION);

    return;
}



sub _LoadRootObject {
    return LoadRootObject();
}

1;