#========================================================================================
# package      DE_EPAGES::Event::Hooks::Attribute
# state        private
#========================================================================================
package DE_EPAGES::Event::Hooks::Attribute;

use DE_EPAGES::Object::API::Factory qw ( GetRootObjectID );
use DE_EPAGES::ThirdPartyConfig::API::Constants qw (ATTRIBUTES_CATEGORY_MISC);

use strict;



#========================================================================================
# function     OnGetThirdPartyConfigAttributes
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnGetThirdPartyConfigAttributes($hParams);
#----------------------------------------------------------------------------------------
# description  API_GetThirdPartyConfigAttributes triggered, register attributes to be
#               configured in PBO
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>AttributesCategory
#                   <li>LanguageID
#               </ul> | ref.hash.*
#========================================================================================
sub OnGetThirdPartyConfigAttributes {
    my ($hParams) = @_;

    return unless $hParams->{'AttributesCategory'} eq ATTRIBUTES_CATEGORY_MISC;
    my $RootObjectID = GetRootObjectID();

    push(
        @{ $hParams->{'Attributes'} }, {
            'SectionID'   => 'Event',
            'SectionName' => 'Event',
            'Attributes'  => [
                { 'ObjectID' => $RootObjectID, 'AttributeAlias' => 'EventCommunicationLog' },
                { 'ObjectID' => $RootObjectID, 'AttributeAlias' => 'EventProcessingEnabled' },
                { 'ObjectID' => $RootObjectID, 'AttributeAlias' => 'EventQueueUrl' },
                { 'ObjectID' => $RootObjectID, 'AttributeAlias' => 'EventProducts' },
                { 'ObjectID' => $RootObjectID, 'AttributeAlias' => 'EventOrders' },
                { 'ObjectID' => $RootObjectID, 'AttributeAlias' => 'EventCategories' },
            ]
        }
    );
    return;
}

1;