#========================================================================================
# package      DE_EPAGES::Event::Hooks::CategoryEvents
# state        public
#----------------------------------------------------------------------------------------
# description  Handler for category-related hooks
#========================================================================================
package DE_EPAGES::Event::Hooks::CategoryEvents;

use DE_EPAGES::Trigger::API::BatchProcessor qw (
    HandleItemInBatchModeOnly
    RegisterHandler
);

use DE_EPAGES::Event::API::Batch::CategoryEventBatchProcessHandler;

use DE_EPAGES::Event::API::Constants qw (
    EVENT_CATEGORY_CREATION
    EVENT_CATEGORY_DELETION
    EVENT_CATEGORY_UPDATE
);

use strict;



sub OnRegisterCreateCategoriesHandler {
    RegisterHandler('CreateCategories', DE_EPAGES::Event::API::Batch::CategoryEventBatchProcessHandler->new());
    return;
};

sub OnRegisterUpdateCategoriesHandler {
    RegisterHandler('UpdateCategories', DE_EPAGES::Event::API::Batch::CategoryEventBatchProcessHandler->new());
    return;
};

sub OnRegisterDeleteCategoriesHandler {
    RegisterHandler('DeleteCategories', DE_EPAGES::Event::API::Batch::CategoryEventBatchProcessHandler->new());
    return;
};



sub OnInsertCategory {
    my ($hParams) = @_;

    my $Category = $hParams->{'Object'};
    if(defined $Category and $Category->instanceOf('Category')) {

        my $EventItem = {
            'Event' => EVENT_CATEGORY_CREATION,
            'Object' => $Category,
        };

        HandleItemInBatchModeOnly(
            'CreateCategories',
            'DE_EPAGES::Event::API::Batch::CategoryEventBatchProcessHandler',
            $EventItem
        );
    }

    return;
}



sub OnDeleteCategory {
    my ($hParams) = @_;

    my $Category = $hParams->{'Object'};
    if(defined $Category and $Category->instanceOf('Category')) {

        my $EventItem = {
            'Event' => EVENT_CATEGORY_DELETION,
            'Object' => $Category,
        };

        HandleItemInBatchModeOnly(
            'DeleteCategories',
            'DE_EPAGES::Event::API::Batch::CategoryEventBatchProcessHandler',
            $EventItem
        );
    }

    return;
}



sub OnAfterUpdateCategory {
    my ($hParams) = @_;

    my $Category = $hParams->{'Object'};
    if(defined $Category and $Category->instanceOf('Category')) {

        my $EventItem = {
            'Event' => EVENT_CATEGORY_UPDATE,
            'Object' => $Category,
        };

        HandleItemInBatchModeOnly(
            'UpdateCategories',
            'DE_EPAGES::Event::API::Batch::CategoryEventBatchProcessHandler',
            $EventItem
        );
    }

    return;
}

1;