#========================================================================================
# package      DE_EPAGES::Ipayment::t::ChangeActionTrigger_SilentErrorOrderAfterPayment_si
# base         DE_EPAGES::Shop::API::TestImportXML
# state        public
#----------------------------------------------------------------------------------------
# description  System Integration test to change action SilentError with order been created after the payment
#========================================================================================
package DE_EPAGES::Ipayment::t::ChangeActionTrigger_SilentErrorOrderAfterPayment_si;
use base DE_EPAGES::Shop::API::TestImportXML;

use DE_EPAGES::Core::API::Error qw ( Error );
use DE_EPAGES::Core::API::PerlTools qw ( isValid );
use DE_EPAGES::Ipayment::API::Database::BasketOrOrder;
use DE_EPAGES::Object::API::Factory qw ( ExistsObject LoadObjectByPath ResetFactoryCaches );
use LWP::UserAgent;
use Test::More;

use strict;

sub test {
    my $self = shift;

    $self->testSilentErrorOrderAfterPayment();
    done_testing();
}

sub testSilentErrorOrderAfterPayment {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $BasketPath = $self->shopPath().'/AnonymousUsers/TestAnonymousUser/Baskets/12345678';
    my $Basket = LoadObjectByPath($BasketPath);
    my $DataBaseBasketOrOrder = DE_EPAGES::Ipayment::API::Database::BasketOrOrder->new();
    ok ($DataBaseBasketOrOrder->extractFromBasketOrOrder($Basket),"$SubTestName - tests if extractFromBasketOrOrder works fine");

    my $SilentErrorURL = $DataBaseBasketOrOrder->getSilentErrorUrl();    note('Used SilentErrorURL: '.$SilentErrorURL);
    my $LineItemPaymentIpayment = $Basket->container()->get('Payment');
    my $LineItemPaymentIpaymentID = $LineItemPaymentIpayment->get('ID');

    if(isValid($LineItemPaymentIpayment->get('TransStatus')) ||
        isValid($LineItemPaymentIpayment->get('TransID'))){
            Error('LineItemPayment TransStatus or TransID are not undef!!!');
    }
    my $UserAgent = LWP::UserAgent->new();

    my $Response = $UserAgent->post($SilentErrorURL, _CreateResponseHash());

    my $ExpectedHttpStatusCode = 200; ## no critic (ProhibitMagicNumbers)
    is($Response->{'_rc'}, $ExpectedHttpStatusCode, "$SubTestName - Test if we get a right response - 200 ok");

    ResetFactoryCaches(); # reset Database cache since this Test-perl process is not the same as the appserver process

    ok(ExistsObject($LineItemPaymentIpaymentID), "$SubTestName - tests if basket still exists");

    return;
}

sub _CreateResponseHash(){
    my $ReturnResponseHash = {
        'shopper_id' => '53AC1BFE-5362-E914-FC55-AC1532072208',
        'REMOTE_ADDR'  => 'WrongIpAddress',
        'ret_status'  => 'ERROR',
        'trx_amount'  => '1000',
        'trx_paymenttyp'  => 'paypal',
        'ret_paymentStatus'  => 'Completed',
        'trx_currency'  => 'EUR',
        'trxuser_id'  => '99999',
        'ret_errorcode'  => '3004',
        'trx_typ'  => 'auth',

        #Those fields are not mandatory, but on the real response we get those params from ipayment
        'ret_errormsg'  => 'Transaction aborted',
        'redirect_needed'  => '0',
        'trx_paymentmethod'  => 'paypal',
        'addr_email'  => 'test.mail@epages.com',
        'addr_street'  => 'Teststr. 123',
        'addr_name'  => 'Test Benutzer',
        'addr_city'  => 'TestCity',
        'addr_zip'  => '12345',
        'invoice_text'  => '',
        'trx_user_comment'  => '',
        'trx_longsafe'  => '0',
        'client_name'  => 'ePages',
        'client_version'  => '',
        'ret_fatalerror'  => '0',
    };
    return $ReturnResponseHash;
}


#----------------------------------------------------------------------------------------
# Methods inherited from DE_EPAGES::Shop::API::Test
#----------------------------------------------------------------------------------------

sub shopAlias {
    return 'ShopWithOrderAfterPayment';
}
sub importXMLPath {
    return 'ShopXMLs/ShopWithOrderAfterPayment.xml';
}

__PACKAGE__->runScript();

1;
