var system = require('system'),
    args = system.args,
    page = require('webpage').create(),
    url = args[1],
    timeout = args[2],
    timeoutCounter = 0;

// set pageload timeout (retry loading on timeout)
page.settings.resourceTimeout = 5000;
page.onResourceTimeout = function(e) {
    if (timeoutCounter > 5) {
        console.log('{"name": "' + url.split('?test=')[1] + '", "success": ' + false + ', "error": "pageload"}');
        phantom.exit();
    }

    timeoutCounter++;
    console.log('Warning: Timeout while loading URL. Trying again...');
    page = require('webpage').create();
    page.open(url, openCallback);
};

// inital loading of page
page.open(url, openCallback);

function openCallback(status) {
    var testsCompleted = function() {
            // get test data
            var testsRun = page.evaluate(function() {
                    var item = document.querySelector('.total');
                    return (item !== null) ? item.innerText : undefined;
                }),
                testsFailed = page.evaluate(function() {
                    var item = document.querySelector('.failed');
                    return (item !== null) ? item.innerText : undefined;
                }),
                testsFailedData = page.evaluate(function() {
                    var items = document.querySelectorAll('ol.qunit-assert-list > li.fail > span.test-message'),
                        data = [],
                        x;

                    if (items && items.length > 0) {
                        for (x = 0; x < items.length; x++) {
                            data.push(items[x].innerText.replace(/"/g, '\''));
                        }

                        return data;
                    }

                    return undefined;
                });

            // clear completion test timer
            clearInterval(checkTestTimer);

            // output results as json object to main process
            console.log('{"name": "' + url.split('?test=')[1] + '","tests": "' + testsRun + '", "fails": "' + testsFailed + '", "success": ' + ((testsFailed == 0) ? 'true' : 'false, "error": "testfailure", "errorData": "' + JSON.stringify(testsFailedData).replace(/"/g, '\\"') + '"') + '}');

            phantom.exit();
        },
        checkCompletion = function() {
            // get content of result div and check if children have been added to test ol-element
            var result = page.evaluate(function() {
                    var item = document.querySelector('.result');
                    return (item !== null) ? item.innerText : undefined;
                }),
                initialized = page.evaluate(function() {
                    var item = document.getElementById('qunit-tests');
                    return (item !== null) ? (item.childElementCount > 0) : false;
                });

            // if initialized, check for completion
            if (initialized) {
                return /(R|r)unning/.test(result) ? false : /Tests completed/.test(result) ? true : false;
            }

            return false;
        },
        timeoutFail = function() {
            console.log('{"name": "' + url.split('?test=')[1] + '", "success": ' + false + ', "error": "timeout"}');

            phantom.exit();
        },
        checkTestTimer;

    // initial start
    checkTestTimer = window.setInterval(function(){
        if (checkCompletion()) {
            testsCompleted();
        }
    }, 250);

    // set hard timeout for tests
    window.setTimeout(timeoutFail, parseInt(timeout)*1000);
};
