#========================================================================================
# package      DE_EPAGES::Order::API::BasketOrderValidator
# base         Exporter
# state        public
#----------------------------------------------------------------------------------------
# description  Checks if a given object is a valid basket or order.
#========================================================================================
package DE_EPAGES::Order::API::BasketOrderValidator;
use base Exporter;

use strict;

our @EXPORT_OK = qw ( IsAValidBasketOrOrder );

#========================================================================================
# function     IsAValidBasketOrOrder
# state        public
#----------------------------------------------------------------------------------------
# syntax       IsAValidBasketOrOrder($BasketOrOrder);
#----------------------------------------------------------------------------------------
# description  Checks if a given object is a valid basket or order.
#----------------------------------------------------------------------------------------
# input        $BasketOrOrder | Basket or order | object
# return       $IsAValidBasketOrOrder |  | object
#========================================================================================
sub IsAValidBasketOrOrder {
    my ($BasketOrOrder) = @_;

    return 0 unless defined($BasketOrOrder);
    return 1 if (_isABasket($BasketOrOrder) || _isAnOrder($BasketOrOrder));
    return 0;
}

#========================================================================================
# function     _isAnOrder
# state        private
#----------------------------------------------------------------------------------------
# syntax       $self->_isAnOrder($BasketOrOrder);
#----------------------------------------------------------------------------------------
# description  Checks if a given object is an order.
#----------------------------------------------------------------------------------------
# input        $BasketOrOrder | Basket or order                              | object
# return       $IsAnOrder     | Whether the given object is an order or not. | object
#========================================================================================
sub _isAnOrder {
    my ($BasketOrOrder) = @_;

    return $BasketOrOrder->instanceOf('CustomerOrder');
}

#========================================================================================
# function     _isABasket
# state        private
#----------------------------------------------------------------------------------------
# syntax       $self->_isABasket($BasketOrOrder);
#----------------------------------------------------------------------------------------
# description  Checks if a given object is a basket.
#----------------------------------------------------------------------------------------
# input        $BasketOrOrder | Basket or order                              | object
# return       $IsAnOrder     | Whether the given object is a basket or not. | object
#========================================================================================
sub _isABasket {
    my ($BasketOrOrder) = @_;

    return $BasketOrOrder->instanceOf('Basket');
}

1;