﻿#========================================================================================
# §package      DE_EPAGES::ShopNewsletter::DAL::Newsletter
# §state        private
# §description  database interface for tables:
#               <ul>
#                   <li>newsletteraddressee
#               </ul>
#========================================================================================
package DE_EPAGES::ShopNewsletter::DAL::Newsletter;
use base qw ( Exporter );

use utf8;
use strict;
our @EXPORT_OK = qw (
    DAL_GetIsSubscribed
);

use DE_EPAGES::Database::API::Connection qw ( GetCurrentDBHandle );
use DE_EPAGES::ShopNewsletter::DAL::SQL::Newsletter;

#========================================================================================
# §function     DAL_GetIsSubscribed
#----------------------------------------------------------------------------------------
# §syntax       $isEmailSubscribed = DAL_GetIsSubscribed($newsletterCampaignID, $email);
#----------------------------------------------------------------------------------------
# §example      $isEmailSubscribed = DAL_GetIsSubscribed(42217, 'oliverzscheyge@gmail.com');
#----------------------------------------------------------------------------------------
# §description  Returns whether a email address is subscribed (and confirmed)
#               for a newsletter campaign.
#----------------------------------------------------------------------------------------
# §input        $newsletterCampaignID | Newsletter campaign ID | int
# §input        $email | Email address to check | string
# §return       $isSubscribed | 1 if email is subscribed, 0 if not | int/bool
#========================================================================================
sub DAL_GetIsSubscribed {
    my ($newsletterCampaignID, $email) = @_;
    my $dbi = GetCurrentDBHandle();
    return DE_EPAGES::ShopNewsletter::DAL::SQL::Newsletter->GetIsSubscribed($dbi, $newsletterCampaignID, $email);
}

1;

