﻿#========================================================================================
# §package      DE_EPAGES::ShopNewsletter::DAL::SQL::Newsletter
# §state        private
# §description  Generic SQL database interface for tables:
#               <ul>
#                   <li>newsletteraddressee
#               </ul>
#========================================================================================
package DE_EPAGES::ShopNewsletter::DAL::SQL::Newsletter;

use utf8;
use strict;

#========================================================================================
# §function     GetIsSubscribed
#----------------------------------------------------------------------------------------
# §syntax       $isEmailSubscribed = $Package->GetIsSubscribed($dbi, $newslettercampaignid, $email);
#----------------------------------------------------------------------------------------
# §example      $isEmailSubscribed = $Package->GetIsSubscribed($dbi, 42237, "ozscheyge@epages.com");
#----------------------------------------------------------------------------------------
# §description  Returns whether a email address is subscribed (and confirmed) to a newsletter.
#----------------------------------------------------------------------------------------
# §input        $dbi | database handle | DE_EPAGES::Database::API::DBI
# §input        $newslettercampaignid | ID of the newsletter campaign | int
# §input        $email | Email address to check | string
# §return       $isSubscribed | 1 if email is subscribed, 0 if not | int/bool
#========================================================================================
sub GetIsSubscribed {
    shift;
    my ($dbi, $newslettercampaignid, $email) = @_;
    my $aaDBResult = $dbi->execute('SELECT unsubscribed FROM newsletteraddressee WHERE newslettercampaignid=? AND email=?', [$newslettercampaignid, $email], ['Integer']);
    if (scalar @$aaDBResult) {
        return 1 if $aaDBResult->[0]->[0] == 0;
    }
    return 0;
}

1;
